@@ -108,9 +108,6 @@ def main():
     elif args.clean:
         return clean()
 
-    if args.pre:
-        args.parse_mode = "markdown"
-
     if args.parse_mode == "markdown":
         # Use the improved MarkdownV2 format by default
         args.parse_mode = telegram.constants.PARSEMODE_MARKDOWN_V2
@@ -119,20 +116,11 @@ def main():
         message = sys.stdin.read()
         if len(message) == 0:
             sys.exit(0)
-        if args.pre:
-            message = pre(message)
-        for c in conf:
-            send(
-                messages=[message],
-                conf=c,
-                parse_mode=args.parse_mode,
-                silent=args.silent,
-                disable_web_page_preview=args.disable_web_page_preview,
-                timeout=args.timeout,
-            )
+        args.message = [message]
 
     try:
         if args.pre:
+            args.parse_mode = "html"
             args.message = [pre(m) for m in args.message]
         delete(args.delete)
         message_ids = []
@@ -156,7 +144,6 @@ def main():
         if args.showids and message_ids:
             smessage_ids = [str(m) for m in message_ids]
             print("message_ids " + " ".join(smessage_ids))
-
     except ConfigError as e:
         print(markup(str(e), "red"))
         cmd = "telegram-send --configure"
@@ -397,10 +384,13 @@ def configure(conf, channel=False, group=False, fm_integration=False):
             else:
                 chat_id = "@" + chat_id
         else:
-            print("\nOpen https://web.telegram.org in your browser, sign in and open your private channel."
-                  "\nNow copy the URL in the address bar and enter it here:")
+            print(
+                "\nOpen https://web.telegram.org/?legacy=1#/im in your browser, sign in and open your private channel."
+                "\nNow copy the URL in the address bar and enter it here:")
             url = input(markup(prompt, "magenta")).strip()
-            chat_id = "-100" + re.match(r".+web\.(telegram|tlgr)\.org\/#\/im\?p=c(\d+)", url).group(2)
+            # example: https://web.telegram.org/?legacy=1#/im?p=c1498081025_17886896740758033425
+            match = re.match(r".+web\.(telegram|tlgr)\.org\/\?legacy=1#\/im\?p=c(?P<chat_id>\d+)_\d+", url)
+            chat_id = "-100" + match.group("chat_id")
 
         authorized = False
         while not authorized:
